@@ -44,6 +44,7 @@ class Player(QMediaPlayer):
         self.parent.back10Btn.setEnabled(True)
         self.parent.for10Btn.setEnabled(True)
         self.parent.timeSlider.setEnabled(True)
+        self.parent.timeSlider.setEnabled(True)
 
     def playPause(self):
         icon = QIcon.fromTheme("media-playback-pause")
@@ -70,6 +71,7 @@ class Player(QMediaPlayer):
         self.queueList.setCurrentIndex(0)
         self.parent.curPCLabel.setText(data['pc_title'])
         self.parent.curTrackName.setText(data['title'])
+        self.parent.curTrackName.setToolTip(data['title'])
         self.player.play()
         icon = QIcon.fromTheme("media-playback-pause")
         self.parent.playBtn.setIcon(icon)
@@ -117,6 +119,8 @@ class Player(QMediaPlayer):
             data = self.queueData[pos]
             self.parent.curPCLabel.setText(data['pc_title'])
             self.parent.curTrackName.setText(data['title'])
+            self.parent.curTrackName.setToolTip(data['title'])
+            self.parent.infoEpisodeLabel.setText('')
             windowTitle = '{0} - {1}'.format(data['pc_title'], data['title'])
             self.parent.setWindowTitle(windowTitle)
             if self.queueList.mediaCount() > 1:
@@ -187,3 +191,16 @@ class Player(QMediaPlayer):
             self.queueData[pos]['url'] = url
             self.queueList.removeMedia(pos)
             self.queueList.insertMedia(pos, QMediaContent(QUrl(url)))
+
+    def changePos(self, pos):
+        prevPos = self.queueList.currentIndex()
+        if prevPos > -1:
+            prevItem = self.parent.queueList.item(prevPos)
+            prevWidget = self.parent.queueList.itemWidget(prevItem)
+            if prevItem:
+                prevWidget.statusIcon.setPixmap(QPixmap())
+
+        self.queueList.setCurrentIndex(pos)
+        self.playlistPosChanged()
+        if self.player.state() == QMediaPlayer.StoppedState or self.player.state() == QMediaPlayer.PausedState:
+            self.player.play()
